redvox.cloud.errors API documentation
Description: Custom defined RedVox Cloud derived errors.

# Module `redvox.cloud.errors`

Custom defined RedVox Cloud derived errors.

Expand source code

    """
    Custom defined RedVox Cloud derived errors.
    """

    class CloudApiError(Exception):
        """
        A generic Cloud API error.
        """

    class AuthenticationError(CloudApiError):
        """
        A cloud authentication error.
        """

        def __init__(self):
            super().__init__("Authentication Error")

    class ApiConnectionError(CloudApiError):
        """
        A connection error.
        """

        def __init__(self, message: str = ""):
            super().__init__(f"ApiConnectionError: {message}")

## Classes

`class ApiConnectionError (message: str = '')`

  A connection error.

  Expand source code

      class ApiConnectionError(CloudApiError):
          """
          A connection error.
          """

          def __init__(self, message: str = ""):
              super().__init__(f"ApiConnectionError: {message}")

  ### Ancestors

  - CloudApiError
  - builtins.Exception
  - builtins.BaseException
`class AuthenticationError`

  A cloud authentication error.

  Expand source code

      class AuthenticationError(CloudApiError):
          """
          A cloud authentication error.
          """

          def __init__(self):
              super().__init__("Authentication Error")

  ### Ancestors

  - CloudApiError
  - builtins.Exception
  - builtins.BaseException
`class CloudApiError (*args, **kwargs)`

  A generic Cloud API error.

  Expand source code

      class CloudApiError(Exception):
          """
          A generic Cloud API error.
          """

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException

  ### Subclasses

  - ApiConnectionError
  - AuthenticationError